markuptools.MarkupCommand
=========================

.. abjad-lineage:: abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand

.. autoclass:: abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.args
   :noindex:

.. autoattribute:: abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.command
   :noindex:

.. autoattribute:: abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.__eq__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.__ge__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.__gt__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.__le__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.__lt__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.__ne__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.__repr__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupCommand.MarkupCommand.MarkupCommand.__str__
   :noindex:
